**Example 1: 创建告警通知接收组**



Input: 

```
tccli pts CreateAlertChannel --cli-unfold-argument  \
    --NoticeId notice-f0yvdmql \
    --ProjectId project-btksohr0
```

Output: 
```
{
    "Response": {
        "RequestId": "70805f6a-d7e1-4247-9d5a-fde3afe2b377"
    }
}
```

